| Title: | Jester Dataset for 'recommenderlab' |
|---|---|
| Description: | Provides the Jester Dataset for package recommenderlab. |
| Authors: | Michael Hahsler [aut, cre, cph] (ORCID: <https://orcid.org/0000-0003-2716-1405>) |
| Maintainer: | Michael Hahsler <[email protected]> |
| License: | GPL-2 |
| Version: | 0.2-0 |
| Built: | 2026-06-05 07:47:59 UTC |
| Source: | https://github.com/mhahsler/recommenderlabJester |
The data set contains the anonymous ratings data from the Jester Online Joke Recommender System collected between April 1999 and May 2003.
data(Jester)data(Jester)
The format is: Formal class 'realRatingMatrix' [package "recommenderlab"]
24983 x 100 rating matrix (24983 users and 100 jokes) with 1,810,455 ratings between -10.00 and +10.00. All selected users have rated 15 or more jokes.
The text for the jokes are also available as a character vector of length 100
in JesterJokes.
Ken Goldberg, Theresa Roeder, Dhruv Gupta, and Chris Perkins. "Eigentaste: A Constant Time Collaborative Filtering Algorithm." Information Retrieval, 4(2), 133-151. July 2001.
data(Jester) Jester hist(getRatings(Jester), main = "Distribution of ratings") # what is the best joke? (highest average rating) best <- which.max(colMeans(Jester)) cat(JesterJokes[best])data(Jester) Jester hist(getRatings(Jester), main = "Distribution of ratings") # what is the best joke? (highest average rating) best <- which.max(colMeans(Jester)) cat(JesterJokes[best])